@@ -1,3 +1,4 @@
+\dontrun{
 # read in the example data (generated, not real student data)
 sdf <- readNAEP(system.file("extdata/data", "M36NT2PM.dat", package="NAEPprimer"))
 
@@ -15,4 +16,4 @@ nrow(mydat1)
 mydat2 <- getData(sdf, varnames=c("dsex", "mrpcm1"), omittedLevels=FALSE,
                   defaultConditions=FALSE)
 nrow(mydat2)
-
+}
