@@ -1,3 +1,4 @@
+\dontrun{
 # read in the example data (generated, not real student data)
 sdf <- readNAEP(system.file("extdata/data", "M36NT2PM.dat", package="NAEPprimer"))
 
@@ -20,3 +21,4 @@ searchSDF(string="value", data=sdf, levels=TRUE)
 # save the search as an object to return a full data.frame of search
 ddf <- searchSDF(string="value", data=sdf, levels=TRUE)
 ddf
+}
