@@ -702,24 +702,3 @@ mmlSumREF <- c("Call:",
                "Weighted observations = 8226.97" )
 mmlDsexIntREF <- c("  (Intercept)    dsexFemale Population SD ",
                    "       279.23          0.34         34.85 ")
-mmlDsexSumREF <- c("Call:",
-                   "mml.sdf(formula = algebra ~ 1, data = sdf, weightVar = \"origwt\", ",
-                   "    verbose = TRUE)",
-                   "Summary Call:",
-                   "summary.mml.sdf(object = mmlNAEP)",
-                   "",
-                   "Summary:",
-                   "            Estimate  StdErr t.value dof Pr(>|t|)    ",
-                   "(Intercept)  279.405   0.821 340.366  28   <2e-16 ***",
-                   "---",
-                   "Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1",
-                   "",
-                   "Residual Variance Estimate:",
-                   "              Estimate StdErr",
-                   "Population SD       35   0.55",
-                   "",
-                   "Convergence = converged",
-                   "Iterations = 10",
-                   "LogLike = -70694.61",
-                   "Observations = 16517",
-                   "Weighted observations = 16528.91" )
