@@ -95,7 +95,7 @@ printREF <- c("an edsurvey.data.frame.list with 4 elements",
               "",
               "Element 1",
               "edsurvey.data.frame for 2005 NAEP (Mathematics) in USA",
-              "Dimensions: 46 rows and 302 columns.",
+              "Dimensions: 46 rows and 303 columns.",
               "",
               "There is 1 full sample weight in this edsurvey.data.frame:",
               "  'origwt' with 62 JK replicate weights (the default).",
@@ -118,7 +118,7 @@ printREF <- c("an edsurvey.data.frame.list with 4 elements",
               "Omitted Levels: 'Multiple', 'NA', and 'Omitted'",
               "",
               "User Conditions:",
-              "scrpsu %in% c(5, 45, 56) dsex == \"Male\"",
+              "scrpsu %in% c(\"5\", \"45\", \"56\") dsex == \"Male\"",
               "",
               "Default Conditions:",
               "tolower(rptsamp) == \"reporting sample\"",
@@ -131,7 +131,7 @@ printREF <- c("an edsurvey.data.frame.list with 4 elements",
               "",
               "Element 2",
               "edsurvey.data.frame for 2002 NAEP (Mathematics) in USA",
-              "Dimensions: 46 rows and 302 columns.",
+              "Dimensions: 46 rows and 303 columns.",
               "",
               "There is 1 full sample weight in this edsurvey.data.frame:",
               "  'origwt' with 62 JK replicate weights (the default).",
@@ -154,7 +154,7 @@ printREF <- c("an edsurvey.data.frame.list with 4 elements",
               "Omitted Levels: 'Multiple', 'NA', and 'Omitted'",
               "",
               "User Conditions:",
-              "scrpsu %in% c(75, 76, 78) dsex == \"Male\"",
+              "scrpsu %in% c(\"75\", \"76\", \"78\") dsex == \"Male\"",
               "",
               "Default Conditions:",
               "tolower(rptsamp) == \"reporting sample\"",
@@ -167,7 +167,7 @@ printREF <- c("an edsurvey.data.frame.list with 4 elements",
               "",
               "Element 3",
               "edsurvey.data.frame for 2003 NAEP (Mathematics) in USA",
-              "Dimensions: 28 rows and 302 columns.",
+              "Dimensions: 28 rows and 303 columns.",
               "",
               "There is 1 full sample weight in this edsurvey.data.frame:",
               "  'origwt' with 62 JK replicate weights (the default).",
@@ -203,7 +203,7 @@ printREF <- c("an edsurvey.data.frame.list with 4 elements",
               "",
               "Element 4",
               "edsurvey.data.frame for 2005 NAEP (Mathematics) in USA",
-              "Dimensions: 43 rows and 302 columns.",
+              "Dimensions: 43 rows and 303 columns.",
               "",
               "There is 1 full sample weight in this edsurvey.data.frame:",
               "  'origwt' with 62 JK replicate weights (the default).",
